@@ -8,7 +8,7 @@ Many of them might be moved to python-gammu later
 __author__ = 'Michal Čihař'
 __email__ = 'michal@cihar.com'
 __license__ = '''
-Copyright © 2003 - 2008 Michal Čihař
+Copyright © 2003 - 2009 Michal Čihař
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License version 2 as published by
@@ -572,6 +572,22 @@ ManufacturerMap = {
     'Sharp': 10,
     'Mitsubishi': 11,
     'PalmOne': 12,
+    'BenQ-Siemens': 13,
+    'Philips': 14,
+    'Elson': 15,
+    'Toshiba': 16,
+    'Option': 17,
+    'Onda': 18,
+    'Teltonika': 19,
+    'HTC': 20,
+    'Apple': 21,
+    'Huawei': 22,
+    'Wavecom': 23,
+    'Sierra Wireless': 24,
+    'Lenovo': 25,
+    'Fly': 26,
+    'Simcom': 27,
+    'Sanyo': 28,
 }
 GarbleMap = {
     0: 'atdot',
