@@ -7,7 +7,7 @@ wx events used all around this program.
 __author__ = 'Michal Čihař'
 __email__ = 'michal@cihar.com'
 __license__ = '''
-Copyright © 2003 - 2008 Michal Čihař
+Copyright © 2003 - 2009 Michal Čihař
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License version 2 as published by
@@ -23,11 +23,7 @@ this program; if not, write to the Free Software Foundation, Inc.,
 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 '''
 
-try:
-    from wx.lib.newevent import NewEvent
-except:
-    print 'Please consider updating to newer wxPython, using local copy of newevent'
-    from Wammu.wxcomp.newevent import NewEvent
+from wx.lib.newevent import NewEvent
 
 # create some events:
 ShowMessageEvent, EVT_SHOW_MESSAGE = NewEvent()
