@@ -7,7 +7,7 @@ Phone configuration wizard
 __author__ = 'Michal Čihař'
 __email__ = 'michal@cihar.com'
 __license__ = '''
-Copyright © 2003 - 2008 Michal Čihař
+Copyright © 2003 - 2009 Michal Čihař
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License version 2 as published by
@@ -240,7 +240,7 @@ class PhoneSearchPage(Wammu.Wizard.TextPage):
                         'port': phone[0],
                         'connection': phone[1]
                     })
-            dlg = wx.SingleChoiceDialog(self, _('Select phone to use from bellow list'), _('Select phone'),
+            dlg = wx.SingleChoiceDialog(self, _('Select phone to use from below list'), _('Select phone'),
                                         choices)
             if dlg.ShowModal() == wx.ID_OK:
                 idx = dlg.GetSelection()
@@ -308,13 +308,13 @@ class ManualPage(Wammu.Wizard.MultiInputPage):
 
 class PhonePortPage(Wammu.Wizard.InputPage):
     """
-    Selects phone port.
+    Selects phone device.
     """
     def __init__(self, parent):
         ports, helptext = parent.settings.GetDevices()
         Wammu.Wizard.InputPage.__init__(self, parent,
-                _('Phone port'),
-                _('Please enter port where phone is connected') + ':',
+                _('Phone Device'),
+                _('Please enter device where phone is accessible') + ':',
                 ports,
                 helptext)
 
@@ -348,7 +348,7 @@ class PhoneGammuDriverPage(Wammu.Wizard.ChoicePage):
                     _('Driver to use'),
                     _('Driver to use'),
                     connections, helps,
-                    extratext = _('Please select which driver you want to use. Follow the help text shown bellow to select the best one.')
+                    extratext = _('Please select which driver you want to use. Follow the help text shown below to select the best one.')
                     )
 
     def GetNext(self):
