@@ -7,7 +7,7 @@ Settings dialog
 __author__ = 'Michal Čihař'
 __email__ = 'michal@cihar.com'
 __license__ = '''
-Copyright © 2003 - 2008 Michal Čihař
+Copyright © 2003 - 2009 Michal Čihař
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License version 2 as published by
@@ -291,7 +291,7 @@ class Settings(wx.Dialog):
             _('Automatic'),
             _('Automatic starting with first name'),
             _('Automatic starting with last name'),
-            _('Custom, use format string bellow')
+            _('Custom, use format string below')
             ], size = (250, -1))
         if v == 'auto':
             self.editnameformat.SetSelection(0)
