@@ -7,7 +7,7 @@ Misc functions like charset conversion, entries parsers,..
 __author__ = 'Michal Čihař'
 __email__ = 'michal@cihar.com'
 __license__ = '''
-Copyright © 2003 - 2008 Michal Čihař
+Copyright © 2003 - 2009 Michal Čihař
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License version 2 as published by
@@ -30,6 +30,7 @@ import re
 import wx
 import string
 import os
+import base64
 try:
     import grp
     HAVE_GRP = True
@@ -62,6 +63,8 @@ def GetItemType(txt):
         return 'category'
     elif txt == 'PictureID' or txt == 'RingtoneID' or txt == 'RingtoneFileSystemID':
         return 'id'
+    elif txt == 'Photo':
+        return 'photo'
     else:
         return 'number'
 
@@ -149,7 +152,7 @@ def NormalizeNumber(number):
         resnumber = '+' + resnumber[2:]
     # Detect numbers with international prefix and without +
     # This can be national number in some countries (eg. US)
-    if NumberPrefix[0] == '+' and len(NumberPrefix) > 0 and resnumber[:len(NumberPrefix) - 1] == NumberPrefix[1:]:
+    if len(NumberPrefix) > 0 and NumberPrefix[0] == '+' and resnumber[:len(NumberPrefix) - 1] == NumberPrefix[1:]:
         resnumber = '+' + resnumber
     # Add international prefix
     if resnumber[0] != '+':
@@ -191,6 +194,12 @@ def GetTypeString(type, value, values, linkphone = True):
         if v[-1] == 'L':
             v = v[:-1]
         return v
+    elif t == 'photo':
+        return '<wxp module="Wammu.Image" class="EncodedBitmap">' + \
+                    '<param name="image" value="' + \
+                    base64.b64encode(value) + \
+                    '">' + \
+                    '</wxp>'
     else:
         return StrConv(value)
 
@@ -446,13 +455,15 @@ def FormatError(txt, info):
     elif info['Code'] == gammu.Errors['ERR_INSIDEPHONEMENU']:
         message = _('Please close opened menu in phone and retry, data can not be accessed while you have opened them.')
     elif info['Code'] == gammu.Errors['ERR_TIMEOUT']:
-        message = _('Timeout while trying to communicate with phone. Maybe phone is not connected (for cable) or out of range (for bluetooth or IrDA).')
+        message = _('Timeout while trying to communicate with phone. Maybe phone is not connected (for cable) or out of range (for Bluetooth or IrDA).')
     elif info['Code'] == gammu.Errors['ERR_DEVICENOTEXIST']:
         message = _('Device for communication with phone does not exist. Maybe you don\'t have phone plugged or your configuration is wrong.')
     elif info['Code'] == gammu.Errors['ERR_DEVICENOPERMISSION']:
         message = _('Can not access device for communication with phone.')
         if sys.platform == 'linux2':
             message += ' ' + _('Maybe you need to be member of some group to have acces to device.')
+    elif info['Code'] == gammu.Errors['ERR_NOSIM']:
+        message = _('Can not access SIM card. Please check whether it is properly inserted in phone and/or try to reboot the phone by removing battery.')
     else:
         message = '%s %s\n%s %s\n%s %d' % (_('Description:'), StrConv(info['Text']), _('Function:'), info['Where'], _('Error code:'), info['Code'])
     return StrConv(txt + '\n\n' + message)
@@ -523,9 +534,9 @@ def CheckDeviceNode(curdev):
                 )
     if not os.access(curdev, os.R_OK) or not os.access(curdev, os.W_OK):
         gid =  os.stat(curdev).st_gid
-        if HAVE_GRP:
+        try:
             group = grp.getgrgid(gid)[0]
-        else:
+        except:
             group = str(gid)
         return (-2,
                 _('You don\'t have permissions for %s device!') % curdev,
